@@ -32,7 +32,7 @@ class Redis(object):
 
 class RedisQueue(object):
     """Simple Queue with Redis Backend"""
-    def __init__(self, REDIS_HOST, REDIS_PORT, name, password=None, health_check_interval=5, namespace='queue', **redis_kwargs):
+    def __init__(self, REDIS_HOST, REDIS_PORT, name, password=None, health_check_interval=5, socket_keepalive=True, namespace='queue', **redis_kwargs):
         """The default connection parameters are: host='localhost', port=6379, db=0"""
 
         try:
@@ -108,7 +108,7 @@ class RedisQueue(object):
 
 class RedisSet(object):
     """Simple set with Redis Backend"""
-    def __init__(self, REDIS_HOST, REDIS_PORT, name, password=None, health_check_interval=5, namespace='set', **redis_kwargs):
+    def __init__(self, REDIS_HOST, REDIS_PORT, name, password=None, health_check_interval=5, socket_keepalive=True, namespace='set', **redis_kwargs):
         """The default connection parameters are: host='localhost', port=6379, db=0"""
 
         try:
